Module code

Module code 

Structs

CodeBuffer
A CodeBuffer is a buffer that can be used to generate code without having to keep track of identation. A CodeBuffer contains either plain text which will be indented accoridng to the buffer’s own indent, or nested CodeBuffers which will be intended according to their own indent, on top of the containing buffer’s indent.
IndentOptions
Options for creating indented blocks.