CodeBuffer

Struct CodeBuffer 

pub struct CodeBuffer { /* private fields */ }
A CodeBuffer is a buffer that can be used to generate code without having to keep track of identation. A CodeBuffer contains either plain text which will be indented accoridng to the buffer’s own indent, or nested CodeBuffers which will be intended according to their own indent, on top of the containing buffer’s indent.

Implementations

Source

impl CodeBuffer

pub const fn new() -> Self

Creates a new CodeBuffer with no identation.

pub fn newline(&self)

Adds a single newline character to this code buffer.

pub fn line(&self, text: impl Into<Cow<'static, str>>)

Adds text into the buffer, followed by a new line.

pub fn text(&self, text: impl Into<Cow<'static, str>>)

Adds text into the buffer, as-is.

pub fn indent(&self, indent: Cow<'static, str>) -> Rc<CodeBuffer>

Creates a new indented sub-buffer at the current position.

pub fn indent_with_options(&self, options: IndentOptions) -> Rc<CodeBuffer>

Creates a new indented sub-buffer at the current position.

pub fn section(&self, trailing_newline: bool) -> Rc<CodeBuffer>

Creates a new un-indented sub-buffer at the current position.

pub fn write(self, writer: &mut dyn Write) -> Result<()>

Writes the content of this CodeBuffer into the provided writer.