pub struct IndentOptions {
pub indent: Cow<'static, str>,
pub leading: Option<Cow<'static, str>>,
pub trailing: Option<Cow<'static, str>>,
pub trailing_newline: bool,
}Expand description
Options for creating indented blocks.
Fields
indent: Cow<'static, str>The indentation to add to the current indentation.
leading: Option<Cow<'static, str>>The text to add before the indented block begins. It’ll be suffixed with a newline character.
trailing: Option<Cow<'static, str>>The text to add after the indentated block ends.
trailing_newline: boolWhether a newline should be inserted after the block ends (after the trailing, if one is provided).